===============================
turbo-markdown
===============================


.. image:: https://img.shields.io/pypi/v/turbo_markdown.svg
        :target: https://pypi.python.org/pypi/turbo_markdown

.. image:: https://img.shields.io/travis/wecatch/turbo_markdown.svg
        :target: https://travis-ci.org/wecatch/turbo_markdown

.. image:: https://readthedocs.org/projects/turbo-markdown/badge/?version=latest
        :target: https://turbo-markdown.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/wecatch/turbo_markdown/shield.svg
     :target: https://pyup.io/repos/github/wecatch/turbo_markdown/
     :alt: Updates


A cli tool to view local markdown files


* Free software: MIT license
* Documentation: https://turbo-markdown.readthedocs.io.


Get Started
-------------

Install and use turbo_markdown::

    pip install turbo-markdown
    cd markdown_dir/
    turbo-markdown

